@@ -10,6 +10,7 @@ from shlex import split
 from site import getsitepackages
 from sys import platform
 from time import sleep
+from copy import deepcopy
 
 import jsonpickle
 import numpy
@@ -18,13 +19,14 @@ import xarray as xr
 
 from pyplan_core import cubepy
 from pyplan_core.classes.BaseNode import BaseNode
+from pyplan_core.classes.evaluators.Evaluator import Evaluator
 from pyplan_core.classes.Intellisense import Intellisense
 from pyplan_core.classes.IOModule import IOModule
-from pyplan_core.classes.PyplanFunctions import Selector, PyplanFunctions
-from pyplan_core.classes.evaluators.Evaluator import Evaluator
+from pyplan_core.classes.PyplanFunctions import PyplanFunctions, Selector
 from pyplan_core.classes.wizards import (CalculatedField, DataframeGroupby,
                                          DataframeIndex, SelectColumns,
-                                         SelectRows, sourcecsv, DataarrayFromPandas)
+                                         SelectRows, sourcecsv, DataarrayFromPandas, InputTable)
+from .DefaultNodeFormats import default_formats                                         
 
 
 class Model(object):
@@ -38,7 +40,6 @@ class Model(object):
 
     def __init__(self, WSClass=None):
         self._nodeDic = {}
-        self._nodeClassDic = dict()
         self._modelProp = {}
         self._modelNode = None
         self._isLoadingModel = False
@@ -80,8 +81,9 @@ class Model(object):
         return os.getpid()
 
     def getDefaultNodeFormat(self, nodeClass):
-        if nodeClass in self._nodeClassDic:
-            return self._nodeClassDic[nodeClass]
+        default_formats
+        if nodeClass in default_formats:
+            return deepcopy(default_formats[nodeClass])
         else:
             return None
 
@@ -116,12 +118,8 @@ class Model(object):
             self._modelNode.title = modelName
 
         self._scenarioDic = dict()
-        self._nodeClassDic = dict()
         self._wizard = None
 
-    def setNodeClassDic(self, nodeClassDic):
-        """Set nodeclass dic used for create new nodes"""
-        self._nodeClassDic = nodeClassDic
 
     def connectToWS(self, company_code, session_key):
         # Connect to WS
@@ -452,7 +450,6 @@ class Model(object):
         self._modelProp = {}
         self._modelNode = None
         self._scenarioDic = dict()
-        self._nodeClassDic = dict()
         self._wizard = None
         self._customImports = None
 
@@ -1322,28 +1319,25 @@ class Model(object):
         node.title = 'TaskLog endpoint'
         node.definition = "result = ''"
 
-    def createSymlinks(self, path):
-
+    def createSymlinks(self, fileName):
         if os.getenv('PYPLAN_IDE', '0') != '1' and not os.getenv('ENGINE_MODE', '') in ['fixed', 'local']:
-
             # Add user or public path to system paths
-            pos = path.index('/', path.index('/', path.index('/',
-                                                             path.index('/', path.index('/')+1)+1)+1)+1)
+            path_sep = os.path.sep
+            path_arr = fileName[:fileName.rfind(path_sep)].split(path_sep)
+
+            dest_path = path_sep.join(path_arr[:6 if path_arr[4] == 'Workgroups' else 5])
 
             # Get python folder path
             python_folder = f'python{sys.version[:3]}'
             try:
-                folder_list = os.listdir(
-                    os.path.join(path[:pos], '.venv', 'lib'))
+                folder_list = os.listdir(os.path.join(dest_path, '.venv', 'lib'))
                 python_folder = folder_list[len(folder_list)-1]
             except Exception as ex:
                 pass
 
             # Add user/public library to system paths
-            user_lib_path = os.path.join(
-                path[:pos], '.venv', 'lib', python_folder, 'site-packages')
-            venv_path = os.path.join(
-                '/venv', 'lib', 'python3.7', 'site-packages')
+            user_lib_path = os.path.join(dest_path, '.venv', 'lib', python_folder, 'site-packages')
+            venv_path = os.path.join('/venv', 'lib', 'python3.7', 'site-packages')
 
             if not os.path.isdir(user_lib_path):
                 os.makedirs(user_lib_path, exist_ok=True)
@@ -1551,6 +1545,9 @@ class Model(object):
             return DataframeGroupby.Wizard()
         elif key == 'dataarrayfrompandas':
             return DataarrayFromPandas.Wizard()
+        elif key == 'inputtable':
+            return InputTable.Wizard()
+            
 
     def getSystemResources(self, onlyMemory=False):
         """Return current system resources"""
